==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridToolbarTitleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarTitleDescription } from "./WebGridToolbarTitleDescription";
/**
 * @hidden
 */
var WebGridToolbarTitleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarTitleDescriptionMetadata, _super);
    function WebGridToolbarTitleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarTitleDescriptionMetadata.b = function (a) {
        if (WebGridToolbarTitleDescriptionMetadata.a == null) {
            WebGridToolbarTitleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarTitleDescriptionMetadata.c(WebGridToolbarTitleDescriptionMetadata.a);
        }
        if (a.j(WebGridToolbarTitleDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridToolbarTitleDescriptionMetadata.a);
    };
    WebGridToolbarTitleDescriptionMetadata.c = function (a) {
        WebGridToolbarContentDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarTitle");
        a.item("__tagNameWC", "String:igc-grid-toolbar-title");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("Name", "String");
    };
    WebGridToolbarTitleDescriptionMetadata.d = function (a) {
        WebGridToolbarTitleDescriptionMetadata.b(a);
        a.aa("WebGridToolbarTitle", function () { return new WebGridToolbarTitleDescription(); });
        a.z("WebGridToolbarTitle", WebGridToolbarTitleDescriptionMetadata.a);
    };
    WebGridToolbarTitleDescriptionMetadata.$t = markType(WebGridToolbarTitleDescriptionMetadata, 'WebGridToolbarTitleDescriptionMetadata');
    WebGridToolbarTitleDescriptionMetadata.a = null;
    return WebGridToolbarTitleDescriptionMetadata;
}(Base));
export { WebGridToolbarTitleDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridToolbarTitleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarTitleDescription } from "./WebGridToolbarTitleDescription";
/**
 * @hidden
 */
var WebGridToolbarTitleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarTitleDescriptionMetadata, _super);
    function WebGridToolbarTitleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarTitleDescriptionMetadata.b = function (a) {
        if (WebGridToolbarTitleDescriptionMetadata.a == null) {
            WebGridToolbarTitleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarTitleDescriptionMetadata.c(WebGridToolbarTitleDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarTitleDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridToolbarTitleDescriptionMetadata.a);
    };
    WebGridToolbarTitleDescriptionMetadata.c = function (a) {
        WebGridToolbarContentDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarTitle");
        a.item("__tagNameWC", "String:igc-grid-toolbar-title");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("Name", "String");
    };
    WebGridToolbarTitleDescriptionMetadata.d = function (a) {
        WebGridToolbarTitleDescriptionMetadata.b(a);
        a.ac("WebGridToolbarTitle", function () { return new WebGridToolbarTitleDescription(); });
        a.ab("WebGridToolbarTitle", WebGridToolbarTitleDescriptionMetadata.a);
    };
    WebGridToolbarTitleDescriptionMetadata.$t = markType(WebGridToolbarTitleDescriptionMetadata, 'WebGridToolbarTitleDescriptionMetadata');
    WebGridToolbarTitleDescriptionMetadata.a = null;
    return WebGridToolbarTitleDescriptionMetadata;
}(Base));
export { WebGridToolbarTitleDescriptionMetadata };
